==> hermes-5.5.0.11.tar.gz: hermes-5.5.0.11/spec/jobs/hermes/log_job_spec.rb <==
require 'rails_helper'

RSpec.describe Hermes::LogJob do
  subject { Hermes::LogJob }
  let(:redis_key) { 'redis_hermes_logs_queue' }

  before(:each) do
    $redis.del(redis_key)
  end

  it 'should set logs in queue' do
    perform_enqueued_jobs do
      subject.perform_now(code: '1234', action: 'test')
      queue = $redis.get redis_key
      expect(queue).not_to be_nil
    end
  end

  it 'should no create log if queue is not full' do
    perform_enqueued_jobs do
      5.times do
        subject.perform_now(code: '1234', action: 'test')
      end
      queue = $redis.get redis_key
      expect(queue).not_to be_nil

      queue = JSON.parse queue
      expect(queue).to be_an_instance_of(Array)
      expect(queue.count).to eq(5)
      expect(Log.count).to eq(0)
    end
  end

  it 'should create log if queue is full' do
    perform_enqueued_jobs do
      10.times do
        subject.perform_now(code: '1234', action: 'test')
      end
      
      expect(Log.count).to eq(10)
    end
  end

  it 'should create log if queue is full and keep other' do
    perform_enqueued_jobs do
      15.times do
        subject.perform_now(code: '1234', action: 'test')
      end
      
      expect(Log.count).to eq(10)
      queue = JSON.parse($redis.get(redis_key))

      expect(queue).not_to be_nil
      expect(queue).to be_an_instance_of(Array)
      expect(queue.count).to eq(5)
    end
  end

  it 'should use default values' do
    subject.perform_now(code: '1234', action: 'test')
    queue =  JSON.parse($redis.get(redis_key))
    expect(queue.first['level']).to eq('info')
    expect(queue.first['domain']).to eq('api')
  end

  it 'should surchage default values' do
    subject.perform_now(code: '1234', action: 'test', level: 'debug', domain: 'lol')
    queue =  JSON.parse($redis.get(redis_key))
    expect(queue.first['level']).to eq('debug')
    expect(queue.first['domain']).to eq('lol')
  end

  it 'Log model created' do 
    15.times do
      subject.perform_now(code: '1234', action: 'test')
    end

    expect(Log.where(code: '1234').count).to eq(10)
  end 
end

==> hermes-5.6.0.1.tar.gz: hermes-5.6.0.1/spec/jobs/hermes/log_job_spec.rb <==
require 'rails_helper'

RSpec.describe Hermes::LogJob do
  subject { Hermes::LogJob }
  let(:redis_key) { 'redis_hermes_logs_queue' }

  before(:each) do
    $redis.del(redis_key)
  end

  it 'should set logs in queue' do
    perform_enqueued_jobs do
      subject.perform_now(code: '1234', action: 'test')
      queue = $redis.get redis_key
      expect(queue).not_to be_nil
    end
  end

  it 'should no create log if queue is not full' do
    perform_enqueued_jobs do
      5.times do
        subject.perform_now(code: '1234', action: 'test')
      end
      queue = $redis.get redis_key
      expect(queue).not_to be_nil

      queue = JSON.parse queue
      expect(queue).to be_an_instance_of(Array)
      expect(queue.count).to eq(5)
      expect(Log.count).to eq(0)
    end
  end

  it 'should create log if queue is full' do
    perform_enqueued_jobs do
      10.times do
        subject.perform_now(code: '1234', action: 'test')
      end
      
      expect(Log.count).to eq(10)
    end
  end

  it 'should create log if queue is full and keep other' do
    perform_enqueued_jobs do
      15.times do
        subject.perform_now(code: '1234', action: 'test')
      end
      
      expect(Log.count).to eq(10)
      queue = JSON.parse($redis.get(redis_key))

      expect(queue).not_to be_nil
      expect(queue).to be_an_instance_of(Array)
      expect(queue.count).to eq(5)
    end
  end

  it 'should use default values' do
    subject.perform_now(code: '1234', action: 'test')
    queue =  JSON.parse($redis.get(redis_key))
    expect(queue.first['insert_one']['level']).to eq('info')
    expect(queue.first['insert_one']['domain']).to eq('api')
  end

  it 'should surchage default values' do
    subject.perform_now(code: '1234', action: 'test', level: 'debug', domain: 'lol')
    queue =  JSON.parse($redis.get(redis_key))
    expect(queue.first['insert_one']['level']).to eq('debug')
    expect(queue.first['insert_one']['domain']).to eq('lol')
  end

  it 'Log model created' do 
    15.times do
      subject.perform_now(code: '1234', action: 'test')
    end

    expect(Log.where(code: '1234').count).to eq(10)
  end 

  describe 'test performance' do 

    it 'works' do 
      start_time = Time.now
  
      10000.times do |i|
        Hermes::LogJob.perform_now(
          user_id: "test", 
          code: "API-TEST-PERF", 
          action: "test perform #{i}"
        )
      end 
      stop_time = Time.now
      puts "Executed in #{(stop_time - start_time).seconds}"
      expect(Log.where(code:  "API-TEST-PERF").count).to eq(10000)
      expect((stop_time - start_time).seconds < 20).to eq(true)
    end 
  end 
end
